import { __decorate, __metadata } from 'tslib';
import { Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { BaseUIComponent, JSONUtils, BindingProperties, propDescription, PropertyCategories, StyleProperties, CoreService, toXMLResult, DynamicComponentsCoreModule } from '@ngx-dynamic-components/core';
import { NgSelectModule } from '@ng-select/ng-select';
import { setTheme } from 'ngx-bootstrap/utils';
import { TabsModule } from 'ngx-bootstrap/tabs';

const packageName = 'bootstrap';

let SelectComponent = class SelectComponent extends BaseUIComponent {
    onSelect() {
        this.changedDataModel.emit(this.dataModel);
        this.emitEvent(this.properties.onSelect);
    }
    get selectStyles() {
        if (this.properties.selectHeight) {
            return {
                height: this.properties.selectHeight
            };
        }
        return null;
    }
    get options() {
        const src = this.properties.itemsSource;
        if (Array.isArray(src)) {
            return src;
        }
        if (typeof src === 'string' && src.startsWith('$.')) {
            return JSONUtils.find(this.dataModel, src);
        }
    }
};
SelectComponent = __decorate([
    Component({
        selector: 'dc-select',
        template: `
  <ng-select [items]="options" (change)="onSelect()" [ngStyle]="selectStyles"
      [(ngModel)]="componentDataModel" [bindLabel]="properties.bindLabel"
      [bindValue]="properties.bindValue || 'value'" [placeholder]="properties.placeholder"></ng-select>
    `,
        styles: [`
    :host ::ng-deep .ng-select.ng-select-single .ng-select-container {
      height: inherit;
      min-height: 30px;
    }
  `]
    })
], SelectComponent);
class SelectProperties extends BindingProperties {
}
__decorate([
    propDescription({
        description: 'Select options or binding to dataModel.',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Object)
], SelectProperties.prototype, "itemsSource", void 0);
__decorate([
    propDescription({
        description: 'Select height.',
        example: '30px',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "selectHeight", void 0);
__decorate([
    propDescription({
        description: 'On Select handler name.',
        example: 'onCountrySelect',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "onSelect", void 0);
__decorate([
    propDescription({
        description: 'Placeholder',
        example: 'Select name',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "placeholder", void 0);
__decorate([
    propDescription({
        description: 'Label property.',
        example: 'name',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "bindLabel", void 0);
__decorate([
    propDescription({
        description: 'Value property.',
        example: 'id',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "bindValue", void 0);
const example = {
    uiModel: `
    <section class="flex-column">
      <section class="form-group">
        <label class="col-form-label" width="60px">Country</label>
        <ng-select onSelect="countryChanged" width="300px" binding="$.country">
          <option value="uk">United Kingdom</option>
          <option value="ua">Ukraine</option>
        </ng-select>
      </section>
      <section class="form-group">
        <label class="col-form-label" width="60px">City</label>
        <ng-select width="300px" itemsSource="$.cities" binding="$.city"></ng-select>
      </section>
    </section>
  `,
    dataModel: {},
    scripts: `
  def countryChanged():
    dataModel.city = null
    if dataModel.country == null:
      dataModel.cities = []
    if dataModel.country == "uk":
      dataModel.cities = [{label: "London", value: "lon"}, {label: "Liverpool", value: "liv"}]
    if dataModel.country == "ua":
      dataModel.cities = [{label: "Kyiv", value: "kyiv"}, {label: "Lviv", value: "lvi"}]
  `,
    title: 'Basic select example'
};
const selectDescriptor = {
    name: 'ng-select',
    label: 'UI Select Input',
    packageName,
    category: "Basic" /* Basic */,
    description: 'NG Select component',
    itemProperties: SelectProperties,
    component: SelectComponent,
    example,
    parseUIModel(xmlRes) {
        const itemProperties = {};
        if (!xmlRes.attrs.itemsSource && xmlRes.childNodes) {
            itemProperties.itemsSource = xmlRes.childNodes.map(r => {
                return { label: r._, value: r.$ && r.$.hasOwnProperty('value') ? r.$.value : r._ };
            });
            xmlRes.childNodes = null;
        }
        return {
            type: 'ng-select',
            itemProperties
        };
    },
    defaultModel: `<ng-select width="100px" itemsSource="$.list" binding="$.value"></ng-select>`,
    propertiesDescriptor: [
        ['selectHeight', { name: 'selectHeight', label: 'Select Height', category: PropertyCategories.Layout }],
    ],
    children: [{
            tag: 'option',
            properties: [{
                    name: 'value',
                    label: 'Option value'
                }]
        }]
};

let TabsComponent = class TabsComponent extends BaseUIComponent {
};
TabsComponent = __decorate([
    Component({
        selector: 'dc-tabs-ui',
        template: `
    <tabset class="tabset-fx w-100 overflow-auto nav-tabs-boxed">
      <tab *ngFor="let item of uiModel.children; let i = index" [heading]="item.itemProperties.header || 'Tab ' + (i + 1)">
      <dc-ui-selector
          (changedDataModel)="changedDataModel.emit(dataModel)"
          (eventHandlers)="eventHandlers.emit($event)"
          [uiModel]="item"
          [dataModel]="dataModel"
          ></dc-ui-selector>
      </tab>
    </tabset>
  `
    })
], TabsComponent);
class TabsProperties extends StyleProperties {
}
const example$1 = {
    title: 'Tabs group example',
    uiModel: `
  <tab-container width="100%" height="100%" margin="8px">
		<tab header="Test tab" padding="0.5rem">
			<text text-style="h1">Tab 1 static text content</text>
		</tab>
    <tab header="Btn tab" class="align-items-start p-2 flex-column">
      <text text-style="h1">Button content</text>
      <button class="btn btn-primary mr-2" onClick="button1_Click">Click</button>
      <section>
        <text text-style="h4">ClickCount:</text>
        <text text-style="h4">$.clickCount</text>
      </section>
		</tab>
	</tab-container>
  `,
    scripts: `
  def button1_Click():
    print("button1_Click")
    if dataModel.clickCount == null:
      dataModel.clickCount = 0
    dataModel.clickCount = dataModel.clickCount + 1
  `,
    dataModel: {}
};
const tabsDescriptor = {
    name: 'tab-container',
    label: 'Tabs container (Bootstrap)',
    packageName,
    category: "Containers" /* Containers */,
    description: 'Tabs component',
    itemProperties: TabsProperties,
    component: TabsComponent,
    example: example$1,
    parseUIModel(xmlData) {
        const children = xmlData.childNodes.map(child => {
            const itemProperties = child.$;
            itemProperties.height = '100%';
            itemProperties.width = '100%';
            return {
                type: 'section',
                children: child.$$.map((r) => CoreService.getUIModel(toXMLResult(r))),
                itemProperties
            };
        });
        return {
            type: 'tab-container',
            children
        };
    },
    children: [{
            tag: 'tab',
            hasChildren: true,
            properties: [{
                    name: 'header',
                    label: 'Tab title'
                }]
        }],
    defaultModel: `<tab-container width="100%" height="100%" margin="8px">
  <tab header="Tab 1" padding="0.5rem">
    <text text-style="h1">Tab 1 static text content</text>
  </tab>
  <tab header="Tab 2" padding="0.5rem">
    <text text-style="h1">Tab 2 static text content</text>
  </tab>
</tab-container>`
};

const COMPONENTS_LIST = [
    tabsDescriptor,
    selectDescriptor
];
// Register components.
function registerComponents() {
    COMPONENTS_LIST.forEach(component => CoreService.registerComponent(component));
}
function getCategories() {
    const categories = COMPONENTS_LIST.reduce((map, desc) => {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }, {});
    return Object.entries(categories).map(([key, val]) => {
        return {
            name: key,
            components: val,
            packageName
        };
    });
}

let DynamicComponentsBootstrapModule = class DynamicComponentsBootstrapModule {
    constructor() {
        setTheme('bs4');
        registerComponents();
    }
};
DynamicComponentsBootstrapModule = __decorate([
    NgModule({
        declarations: [SelectComponent, TabsComponent],
        imports: [
            DynamicComponentsCoreModule,
            CommonModule,
            FormsModule,
            NgSelectModule,
            TabsModule.forRoot()
        ]
    }),
    __metadata("design:paramtypes", [])
], DynamicComponentsBootstrapModule);

/*
 * Public API Surface of bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { COMPONENTS_LIST, DynamicComponentsBootstrapModule, SelectComponent, TabsComponent, getCategories, SelectComponent as ɵa, SelectProperties as ɵb, example as ɵc, selectDescriptor as ɵd, TabsComponent as ɵe, TabsProperties as ɵf, example$1 as ɵg, tabsDescriptor as ɵh, packageName as ɵi };
//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map
